Skip to contents

Log-dinvgamma, based on MCMCpack

Usage

ldinvgamma(x, shape, scale = 1)

Arguments

x

vector of quantiles

shape, scale

shape and scale parameters for the inverse Gamma distribution

Value

log density of the inverse Gamma distribution evaluated at x

Author

Michael Dietze