Skip to contents

Extract current jump parameter values for a mvjump object

Usage

# S3 method for class 'mvjump'
p(x, ...)

Arguments

x

object of class mvjump

...

additional arguments (currently unused)

Value

The most recent row of the multivariate jump parameter history.

Author

Michael Dietze