Skip to contents

Simple interpolation of a density object to new points

Usage

# S3 method for class 'density'
predict(object, xnew, ...)

Arguments

object

a density object (as returned by density)

xnew

numeric vector of new x coordinates at which to evaluate the density

...

additional arguments (currently unused)

Value

numeric vector of interpolated density values at xnew

Author

Michael Dietze