Skip to contents

Adapts the jump standard deviation based on recent acceptance rate to keep acceptance near the target rate.

Usage

# S3 method for class 'jump'
update(object, chain, ...)

Arguments

object

object of class jump

chain

numeric matrix of recent MCMC chain values used to compute acceptance rate

...

additional arguments (currently unused)

Value

Updated jump object with adjusted history and acceptance rate.

Author

Michael Dietze