Skip to contents

Adapts each dimension of the multivariate jump standard deviation based on recent acceptance rate for each dimension to keep acceptance near the target rate.

Usage

# S3 method for class 'mvjump'
update(object, chain, ...)

Arguments

object

object of class mvjump

chain

numeric matrix of recent MCMC chain values used to compute acceptance rates

...

additional arguments (currently unused)

Value

Updated mvjump object with adjusted history and acceptance rates.

Author

Michael Dietze