mvjump
R/p.jump.R
p.mvjump.Rd
Extract current jump parameter values for a mvjump object
# S3 method for class 'mvjump' p(x, ...)
object of class mvjump
additional arguments (currently unused)
The most recent row of the multivariate jump parameter history.
Michael Dietze