Simple interpolation of a density object to new points
Source:R/predict.density.R
predict.density.RdSimple interpolation of a density object to new points
Usage
# S3 method for class 'density'
predict(object, xnew, ...)Arguments
- object
a
densityobject (as returned bydensity)- xnew
numeric vector of new x coordinates at which to evaluate the density
- ...
additional arguments (currently unused)