Adapts the jump standard deviation based on recent acceptance rate to keep acceptance near the target rate.
Usage
# S3 method for class 'jump'
update(object, chain, ...)Adapts the jump standard deviation based on recent acceptance rate to keep acceptance near the target rate.
# S3 method for class 'jump'
update(object, chain, ...)