Update method for adaptive MCMC multivariate jump-tuning objects
Source:R/update.jump.R
update.mvjump.RdAdapts each dimension of the multivariate jump standard deviation based on recent acceptance rate for each dimension to keep acceptance near the target rate.
Usage
# S3 method for class 'mvjump'
update(object, chain, ...)